define((function () { 'use strict';

	const other$1 = {
		something: 'here'
	};

	const other = {
		somethingElse: 'here'
	};

}));
